==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlUI/src/com/clustercontrol/accesscontrol/view/action/UserFilterAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.accesscontrol.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.accesscontrol.dialog.UserFilterDialog;
import com.clustercontrol.accesscontrol.view.UserListView;
import com.clustercontrol.bean.Property;
import com.clustercontrol.util.PropertyUtil;

/**
 * 桼ˤ롢Ԥ󥯥饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class UserFilterAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.accesscontrol.view.action.UserFilterAction";
	
    private IViewPart viewPart;

    /**
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        // 桼ꡢ򤵤Ƥ桼UID

        UserListView view = (UserListView) this.viewPart
                .getAdapter(UserListView.class);

        if (action.isChecked()) {
            // 
            UserFilterDialog dialog = new UserFilterDialog(this.viewPart
                    .getSite().getShell());

            // ˤѹ򤵤줿硢ƤäϿԤ
            if (dialog.open() == IDialogConstants.OK_ID) {
                Property condition = dialog.getInputData();

                PropertyUtil.deletePropertyDefine(condition);
                view.update(condition);
            } else {
                action.setChecked(false);
            }
        } else {
            view.update(null);
        }
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlUI/src/com/clustercontrol/accesscontrol/view/action/UserFilterAction.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.accesscontrol.view.action;

import org.eclipse.jface.action.IAction;
import org.eclipse.jface.dialogs.IDialogConstants;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

import com.clustercontrol.accesscontrol.dialog.UserFilterDialog;
import com.clustercontrol.accesscontrol.view.UserListView;
import com.clustercontrol.bean.Property;
import com.clustercontrol.util.PropertyUtil;

/**
 * ユーザ検索ダイアログによる、検索処理を行うアクションクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class UserFilterAction implements IViewActionDelegate {
	public static final String ID = "com.clustercontrol.accesscontrol.view.action.UserFilterAction";
	
    private IViewPart viewPart;

    /**
     * @see org.eclipse.ui.IViewActionDelegate#init(org.eclipse.ui.IViewPart)
     */
    public void init(IViewPart viewPart) {
        this.viewPart = viewPart;
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#run(org.eclipse.jface.action.IAction)
     */
    public void run(IAction action) {
        // ユーザ一覧より、選択されているユーザのUIDを取得

        UserListView view = (UserListView) this.viewPart
                .getAdapter(UserListView.class);

        if (action.isChecked()) {
            // ダイアログを生成
            UserFilterDialog dialog = new UserFilterDialog(this.viewPart
                    .getSite().getShell());

            // ダイアログにて変更が選択された場合、入力内容をもって登録を行う。
            if (dialog.open() == IDialogConstants.OK_ID) {
                Property condition = dialog.getInputData();

                PropertyUtil.deletePropertyDefine(condition);
                view.update(condition);
            } else {
                action.setChecked(false);
            }
        } else {
            view.update(null);
        }
    }

    /**
     * @see org.eclipse.ui.IActionDelegate#selectionChanged(org.eclipse.jface.action.IAction,
     *      org.eclipse.jface.viewers.ISelection)
     */
    public void selectionChanged(IAction action, ISelection selection) {
    }
}
